pub struct Diagnostic {
pub code: String,
pub severity: DiagnosticSeverity,
pub message: String,
pub line: Option<u32>,
pub column: Option<u32>,
pub end_line: Option<u32>,
pub end_column: Option<u32>,
pub key: Option<SpanKey>,
}Fields
code: Stringseverity: DiagnosticSeveritymessage: Stringline: Option<u32>column: Option<u32>end_line: Option<u32>end_column: Option<u32>key: Option<SpanKey>Structured locator used to resolve source positions in the WASM layer.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
pub fn error(code: &str, message: String) -> Self
pub fn warning(code: &str, message: String) -> Self
pub fn with_position(self, line: u32, column: u32) -> Self
Sourcepub fn at(self, key: SpanKey) -> Self
pub fn at(self, key: SpanKey) -> Self
Attach a structured source locator so the caller can resolve the span.
pub fn is_error(&self) -> bool